notify_systemd

Function notify_systemd 

fn notify_systemd(states: &[NotifyState<'_>], about: &'static str)
Sends notification states to the service manager.

A notification is advisory, so a failure is logged against the name of what could not be sent and never reaches the caller.