fn covers(listening: &SocketAddr, addr: &SocketAddr) -> boolExpand description
Whether a listener on one address answers for another, which is the case when they name the same socket or the listener holds the wider wildcard.
fn covers(listening: &SocketAddr, addr: &SocketAddr) -> boolWhether a listener on one address answers for another, which is the case when they name the same socket or the listener holds the wider wildcard.